Learn R Programming

renv (version 0.5.0-92)

clean: Clean a Project

Description

Clean up a project and its associated R libraries.

Usage

clean(project = NULL, confirm = interactive())

Arguments

project

The project directory. If NULL, then the active project will be used. If no project is currently active, then the current working directory is used instead.

confirm

Boolean; prompt the user before taking any action?

Details

The following actions will be performed:

  • Leftover temporary directories in the project library will be removed.

  • Non-system packages installed in the system library will be removed.

  • Unused packages within the project will be removed.

  • Stale lockfiles (00LOCK-) will be removed.

  • Packages within the cache that are no longer used will be removed.