Learn R Programming

renv (version 0.6.0-7)

history: View Lockfile History

Description

The history() function can be used to search for prior versions of the renv.lock file used within a project.

Usage

history(project = NULL)

Arguments

project

The project directory. If NULL, then the active project will be used. If no project is currently active, then the current working directory is used instead.

Details

The history() function is currently only implemented for projects using git for version control.