Learn R Programming

renv (version 0.6.0-7)

load: Load a Project

Description

Normally, this is done automatically on session startup by the infrastructure generated by activate() -- users should not need to call this function directly.

Usage

load(project = NULL)

Arguments

project

The project directory. If NULL, then the active project will be used. If no project is currently active, then the current working directory is used instead.