| lockfile | R Documentation |
Create an renv lockfile from a variety of sources.
lockfile(from = NULL, to = NULL, project = NULL)
from |
The source from which the lockfile should be created. This can be:
The set of supported sources may be expanded in future releases of
|
to |
The path to a lockfile to be written. When |
project |
The project directory. If |
lockfile() provides a generic entry point for producing an renv
lockfile. The kind of lockfile produced depends on the value supplied as
from; for example, given the path to a Posit Connect manifest.json
file, lockfile() will convert that manifest into a lockfile.
By default the lockfile is returned as an R object. Supply to to also
write it to disk, after which restore() can be used to restore the
associated project library.
An renv lockfile, as an R object of class renv_lockfile. When to
is supplied, the lockfile is returned invisibly.
lockfiles, for a description of the structure of an
renv lockfile.
## Not run:
# create a lockfile from a Posit Connect 'manifest.json' file
lock <- lockfile(from = "manifest.json")
# convert a 'manifest.json' file and write 'renv.lock' in a single call
lockfile(from = "manifest.json", to = "renv.lock")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.