Rebuild and reinstall all of the packages in your project library. This can be useful as a diagnostic tool -- for example, if you find that one or more of your packages fail to load, and you want to ensure that you are starting from a clean slate.
rebuild(packages = NULL, recursive = TRUE, ...,
confirm = interactive(), library = NULL, project = NULL)The package(s) to be rebuilt. When NULL, all packages
in the library will be installed.
Boolean; should dependencies of packages be rebuilt
recursively? Defaults to TRUE.
Optional arguments; reserved for future expansion.
Boolean; prompt the user before taking any action?
The R library to be used. When NULL, the active project
library will be used instead.
The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
Note that binaries will be used when appropriate and available for your
platform. If you'd like to force packages to be rebuilt from sources, you
can set options(pkgType = "source").