Learn R Programming

renv (version 0.6.0-7)

refresh: Refresh the Local Cache of Packages Available on CRAN

Description

Query the active CRAN repositories for available packages, and update the in-memory cache of those packages.

Usage

refresh()

Arguments

Details

Note that R also maintains its own on-disk cache of available packages, which is used by available.packages(). Calling refresh() will force an update of both types of caches. renv prefers using an in-memory cache as on occasion the temporary directory can be slow to access (e.g. when it is a mounted network filesystem).