| rehash | R Documentation |
Re-hash packages in the renv cache, ensuring that any previously-cached packages are copied to a new cache location appropriate for this version of renv. This can be useful if the cache scheme has changed in a new version of renv, but you'd like to preserve your previously-cached packages.
rehash(prompt = interactive(), ...)
prompt |
Boolean; prompt the user before taking any action? For backwards
compatibility, |
... |
Unused arguments, reserved for future expansion. If any arguments
are matched to |
When re-hashing, packages are relocated to the cache location appropriate
for the active version of renv: they are copied when migrating from a
previous cache version, and moved when re-hashing within the active cache.
Because a package's previous cache location is not retained, project
libraries that still link to that old location will be left with broken
links after a re-hash. Use repair() (or, equivalently, restore())
within those projects to reinstall and re-link the affected packages.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.