| remove | R Documentation |
Remove (uninstall) R packages.
remove(packages, ..., library = NULL, prompt = interactive(), project = NULL)
packages |
A character vector of R packages to remove. |
... |
Unused arguments, reserved for future expansion. If any arguments
are matched to |
library |
The library from which packages should be removed. When
|
prompt |
Boolean; prompt the user before removing packages? The prompt is only shown when removing packages from a library other than the project library. |
project |
The project directory. If |
Note that remove() only removes packages from the requested library;
it does not modify the project lockfile. Use record() if you'd
like to remove a package's record from the lockfile.
A vector of package records, describing the packages (if any) which were successfully removed.
## Not run:
# disable automatic snapshots
auto.snapshot <- getOption("renv.config.auto.snapshot")
options(renv.config.auto.snapshot = FALSE)
# initialize a new project (with an empty R library)
renv::init(bare = TRUE)
# install digest 0.6.19
renv::install("digest@0.6.19")
# save library state to lockfile
renv::snapshot()
# remove digest from library
renv::remove("digest")
# check library status
renv::status()
# restore lockfile, thereby reinstalling digest 0.6.19
renv::restore()
# restore automatic snapshots
options(renv.config.auto.snapshot = auto.snapshot)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.