Revert the lockfile to its contents at a prior commit.
revert(commit = "HEAD", ..., project = NULL)The commit associated with a prior version of the lockfile.
Optional arguments; currently unused.
The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
The revert() function is currently only implemented for projects using
git for version control.