Update packages which are currently out-of-date. Currently, only CRAN and GitHub package sources are supported.
update(packages = NULL, ..., library = NULL, rebuild = FALSE,
confirm = interactive(), project = NULL)A character vector of R packages to update. When NULL,
all packages within the required libraries will be updated.
Optional arguments; reserved for future expansion.
The R library to be used. When NULL, the active project
library will be used instead.
Force packages to be rebuilt, thereby bypassing any installed versions of the package available in the cache? This can either be a boolean (indicating that the requested package(s) should be rebuilt), or a vector of package names indicating which packages should be rebuilt.
Boolean; prompt the user before taking any action?
The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
Updates will only be checked from the same source -- for example, if a package was installed from GitHub, but a newer version is available on CRAN, that updated version will not be seen.