Upgrade the version of renv associated with a project.
upgrade(project = NULL, version = NULL, confirm = interactive())The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
The version of renv to be installed. By default, the
latest version of renv available on CRAN is used.
Boolean; confirm upgrade before proceeding?
This function will attempt to install renv from two locations:
The active CRAN repositories (as specified in getOption("repos"));
From the renv project's GitHub page.
When version = NULL (the default), only the active CRAN repositories will
be consulted. Hence, this can be used to upgrade a project to the latest
released version of renv on CRAN.
If you'd instead like to try out a development version of renv, you can
explicitly request a different version of renv and that version of the
package will be downloaded and installed from GitHub. Use
version = "master" to install the latest development version of renv.