Clean up a project and its associated R libraries.
clean(project = NULL, ..., confirm = interactive())The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
Optional arguments; reserved for future expansion.
Boolean; prompt the user before taking any action?
The following actions will be performed:
Leftover temporary directories in the project library will be removed.
Non-system packages installed in the system library will be removed.
Unused packages within the project will be removed.
Stale lockfiles (00LOCK-) will be removed.
Packages within the cache that are no longer used will be removed.