Learn R Programming

renv (version 0.17.3)

deactivate: Deactivate a Project

Description

Use deactivate() to remove the infrastructure used by renv to activate projects for newly-launched R sessions. In particular, this implies removing the requisite code from the project .Rprofile that automatically activates the project when new R sessions are launched in the project directory.

Usage

deactivate(project = NULL)

Value

The project directory, invisibly. Note that this function is normally called for its side effects.

Arguments

project

The project directory. If NULL, then the active project will be used. If no project is currently active, then the current working directory is used instead.

See Also

Other renv: activate()

Examples

Run this code
if (FALSE) {

# deactivate the currently-activated project
renv::deactivate()

}

Run the code above in your browser using DataLab