Migrate a project's infrastructure from Packrat to renv.
The following actions are taken:
migrate(project = NULL)The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
The Packrat lockfile is migrated to renv.lock;
Packages installed in the Packrat library are migrated to the renv library;
Relevant Packrat options (e.g. ignored.packages) are copied;
Packages in the Packrat cache are imported into the renv cache;
The project .Rprofile is updated to use renv.