- packages
The packages to be included in the plan. When NULL
(the default), all packages currently used in the project will be
included, as determined by dependencies().
- ...
Unused arguments, reserved for future expansion. If any arguments
are matched to ..., renv will signal an error.
- dependencies
A vector of DESCRIPTION field names that should be used
for package dependency resolution. When NULL (the default), the value
of renv::settings$package.dependency.fields is used. The aliases
"strong", "most", and "all" are also supported.
See tools::package_dependencies() for more details.
- lockfile
The path where the generated lockfile should be written.
Use NULL to skip writing the lockfile.
- project
The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.