- project
The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
- ...
Unused arguments, reserved for future expansion. If any arguments
are matched to ..., renv will signal an error.
- library
The library paths to be used during restore. See Library
for details.
- lockfile
The lockfile to be used for restoration of the associated
project. When NULL, the most recently generated lockfile for this project
is used.
- packages
A subset of packages recorded in the lockfile to restore.
When NULL (the default), all packages available in the lockfile will be
restored. Any required recursive dependencies of the requested packages
will be restored as well.
- exclude
A subset of packages to be excluded during restore. This can
be useful for when you'd like to restore all but a subset of packages from
a lockfile. Note that if you attempt to exclude a package which is required
as the recursive dependency of another package, your request will be
ignored.
- rebuild
Force packages to be rebuilt, thereby bypassing any installed
versions of the package available in the cache? This can either be a
boolean (indicating that all installed packages should be rebuilt), or a
vector of package names indicating which packages should be rebuilt.
- repos
The repositories to use during restore, for packages installed
from CRAN or another similar R package repository. When set, this will
override any repositories declared in the lockfile. See also the
repos.override option in config for an alternate way to provide a
repository override.
- clean
Boolean; remove packages not recorded in the lockfile from
the target library? Use clean = TRUE if you'd like the library state
to exactly reflect the lockfile contents after restore().
- prompt
Boolean; prompt the user before taking any action? For backwards
compatibility, confirm is accepted as an alias for prompt.