Run an R script, in the context of a project using renv. The script will
be run within an R sub-process.
Arguments
- script
The path to an R script.
- ...
Unused arguments, reserved for future expansion. If any arguments are matched to
...,renvwill signal an error.- job
Run the requested script as an RStudio job? Requires a recent version of both RStudio and the
rstudioapipackages. WhenNULL, the script will be run as a job if possible, and as a regular R process launched bysystem2()if not.- name
The name to associate with the job, for scripts run as a job.
- project
The path to the
renvproject. This project will be loaded before the requested script is executed. WhenNULL(the default),renvwill automatically determine the project root for the associated script if possible.