- project
The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
- ...
Unused arguments, reserved for future expansion. If any arguments
are matched to ..., renv will signal an error.
- library
The R libraries to snapshot. When NULL, the active R
libraries (as reported by .libPaths()) are used.
- lockfile
The location where the generated lockfile should be written.
By default, the lockfile is written to a file called renv.lock in the
project directory. When NULL, the lockfile (as an R object) is returned
directly instead.
- type
The type of snapshot to perform. See Snapshot Type for
more details.
- repos
The R repositories to be recorded in the lockfile. Defaults
to the currently active package repositories, as retrieved by
getOption("repos").
- packages
A vector of packages to be included in the lockfile. When
NULL (the default), all packages relevant for the type of snapshot being
performed will be included. When set, the type argument is ignored.
Recursive dependencies of the specified packages will be added to the
lockfile as well.
- prompt
Boolean; prompt the user before taking any action? For backwards
compatibility, confirm is accepted as an alias for prompt.
- update
Boolean; if the lockfile already exists, then attempt to update
that lockfile without removing any prior package records.
- force
Boolean; force generation of a lockfile even when pre-flight
validation checks have failed?
- reprex
Boolean; generate output appropriate for embedding the lockfile
as part of a reprex?