Report differences between the project's lockfile and the current state of the private library (if any).
status(project = NULL, ..., library = NULL, lockfile = NULL)The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
Optional arguments; reserved for future expansion.
The path to a library. By default, the project library
associated with the requested project project is used.
The path to a lockfile. By default, the project lockfile
(called renv.lock) is used.