Upgrade the version of renv associated with a project.
upgrade(project = NULL, version = NULL, confirm = interactive())The project directory. If NULL, then the active project will
be used. If no project is currently active, then the current working
directory is used instead.
The version of renv to be installed. By default, the latest
version of renv as available on the active CRAN repositories is used.
Boolean; confirm upgrade before proceeding?
By default, this function will attempt to install the latest version of
renv as available on the active CRAN repositories. If you'd instead like to
try out a development version of renv, you can explicitly request a
different version of renv and that version of the package will be
downloaded and installed from GitHub. Use version = "master" to install the
latest development version of renv, as from the renv project's GitHub page.