| vulns | R Documentation |
This function acts as an interface to Posit Package Manager's vulnerability API, making it possible to ascertain if the provided packages have any known vulnerabilities.
vulns(
packages = NULL,
lockfile = NULL,
...,
repos = NULL,
verbose = FALSE,
project = NULL
)
packages |
A vector of package specifications, of the form
|
lockfile |
The path to an |
... |
Unused arguments, reserved for future expansion. If any arguments
are matched to |
repos |
The Package Manager repository to be queried. |
verbose |
Boolean; when |
project |
The project directory. If |
This function requires the curl package to be installed.
An R list with one entry per requested package. Each entry
contains metadata returned by Posit Package Manager (e.g. name,
version, licenses, blocked), plus a vulns field. The vulns
field is an empty list when the package has no known vulnerabilities,
and otherwise holds one or more vulnerability records.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.